@@ -4,7 +4,7 @@ use strict;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = 0.03;
+$VERSION = '0.04';
 @ISA = qw/Gedcom::Date/;
 
 use Gedcom::Date;
@@ -49,6 +49,12 @@ sub earliest {
     return $self->{date}->earliest;
 }
 
+sub sort_date {
+    my ($self) = @_;
+
+    return $self->{date}->sort_date;
+}
+
 my %text = (
     en => 'on %0',
     nl => 'op %0',
