@@ -4,7 +4,7 @@ use strict;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = 0.03;
+$VERSION = '0.04';
 @ISA = qw/Gedcom::Date/;
 
 use Gedcom::Date;
@@ -40,6 +40,10 @@ sub latest {
     return DateTime::Infinite::Future->new;
 }
 
+sub sort_date {
+    return '????-??-??';
+}
+
 sub as_text {
     my ($self, $lang) = @_;
 
